-- main.lua for simcanvas.lua

simcan = require 'simcanvas'

function love.load()
	gr, li, pi	= love.graphics, love.image, math.pi
	gr.setCaption( ' Using Simulated Canvases' )
	ang		= 0
	gr.setBackgroundColor(255, 255, 255, 0)	-- zero alpha for image background
	bkgnd	= gr.newImage( 'Love.jpg' )	-- background image
	image	= gr.newImage( 'buda.png' )
	wd, ht	= image:getWidth(), image:getHeight()
    screen	= { w = gr.getWidth(), h = gr.getHeight() }
	object_features = {
		function ()
			gr.setColor( {255, 55,185,255} )
			gr.circle( 'fill', 125, 125, 125 )
			gr.setColor( {255,255,255,255} )
			gr.circle( 'fill', 80, 80, 60 )
			gr.setColor( 185,185,185,255 )
			gr.circle( 'line', 80, 80, 60 )
			end,
		function ()
			gr.setColor(255,255,255,255)
			gr.draw( image )	-- draws circle over image loaded from file
			gr.setColor( {255,  0,  0,255})
			gr.circle( 'line', 45, 45, 20 )
			gr.setColor( {255,255,255,255} )
			gr.setFont( gr.newFont( 16 ) )
			gr.print( 'message', 5, 75 )
			gr.rectangle( 'fill', 35, 35, 20, 20 )
			gr.setColor(  0,  0,  0,255)
			gr.print( '2', 40, 35 )
			gr.setColor(0,0,255,255)
			gr.triangle('line',0,89,45,0,89,89)
			end,
		function ()
			gr.setColor(255,255,255,255)
			gr.draw( image )
			gr.setColor(255,255,0,255)
			gr.rectangle( 'fill', 35, 35, 20, 20 )	-- change number from 2 to 3
			gr.setColor(  0,   0,  0,255)
			gr.print( '3',    40, 35 )
			gr.setColor(  0, 255,  0,255)
			gr.line(  0, 0,   90, 90 )
			gr.line( 90, 0,    0, 90 )
			end,
		function ()
			gr.setColor(255,255,255)
			gr.draw( image)
			gr.setColor( 255, 255,   0, 255 )
			gr.line( 0, 0, wd, ht )
			gr.line( 0, wd, ht, 0 )
			gr.rectangle( 'line', 0, 0, wd, ht )
			gr.setColor(   0, 255,   0, 255 )
			gr.circle( 'line', 45, 45, 20 )
			gr.arc( 'fill', 60, 60, 20, 0, pi/2 )
			gr.setColor(   0,   0, 255, 255 )
			gr.rectangle( 'fill', 35, 35, 20, 20 )
			gr.setColor( 255,   0,   0, 255 )
			gr.print( '4', 40, 35, 0 )
			gr.polygon( 'line', 10, 80, 45, 10, 80, 80 )
			end,
		function ()
			gr.setColor( 255, 0, 0, 255 )
			gr.rectangle('fill',0, 0, wd, ht )
			gr.setColor( 255, 255,   0, 255 )
			gr.rectangle('line',1,1,wd-2,ht-2)
			gr.setColor(   0, 255,   0, 255 )
			gr.circle( 'fill', wd/2, ht/2, wd/2 )
			gr.setColor(   0,   0, 255, 255 )
			gr.circle( 'line', wd/2, ht/2, wd/2 )
			gr.setColor(255,255,255,255)
			gr.draw( image, 50, 50, 0, 1, 1, image:getWidth()/2,image:getHeight()/2)
			gr.setColor(   0, 255, 255, 255 )
			gr.rectangle( 'fill', 35, 35, 20, 20 )
			gr.setColor(   0,   0,   0, 255 )
			gr.print( '5', 40, 35 )
			gr.setColor(255,255,0,255)
			data = {10,10,15,10,15,20,10,20,10,30,15,30,15,40,10,40,10,
				50,15,50,15,60,10,60,10,70,15,70,15,80,10,80,10,90,15,90}
			for i = 1, #data - 2, 2 do
				gr.line( data[i], data[i+1], data[i+2], data[i+3] )
				end
			end,
		function ()
			gr.setColor(255,255,255,255)
			gr.draw( image )
			gr.setColor( 255,   0, 255, 255 )
			gr.rectangle( 'fill', 35, 35, 20, 20 )
			gr.setColor(   0,   0,   0, 255 )
			gr.print( '6', 40, 35 )
			end
		}
	create_canvases()	-- create all the canvases needed
	end

function create_canvases()
	object			= {}
	object[1]		= simcan.newCanvas( 250, 250 )	-- creates blank canvas and draws on it
		simcan.setCanvas( object[1] )
		object_features[1]()
		object[1]	= simcan.setCanvas()
	for i = 2, #object_features do
		object[i]	= simcan.newCanvas( wd, ht )
		simcan.setCanvas( object[i] )
		object_features[i]()
		object[i]	= simcan.setCanvas()
		end
	end

function love.draw()
	gr.draw( bkgnd )	-- add background image
	gr.draw( object[1], screen.w/2+0, screen.h/2+0, ang )
	gr.draw( object[2], screen.w/2+0, screen.h/2+0, -ang, 1,1,-90,-90 )
	gr.draw( object[3], 100,100, ang,1,1,45,45 )
	gr.draw( object[4], 100, 500,-ang, 1, 1, 45, 45 )
	gr.draw( object[5], 700, 100, ang/4,1,1, wd/2, ht/2 )
	gr.draw( object[6], 700, 450 )
	gr.setColor( 255, 255, 255, 255 )
	gr.print( 'fps: '..love.timer.getFPS( ), screen.w-95, screen.h-20 )
	end

function love.update( dt )
	ang	= ang + dt
	end

function love.keypressed( key )
	if key	== 'escape' then love.event.push( 'quit' )	end
	end



